| addCosts | R Documentation |
Add Direct Medical Costs to a Cohort
addCosts(
x,
indexDate = "cohort_start_date",
censorDate = NULL,
window = list(c(-365, -1), c(0, 365)),
costField = "total_paid",
domains = c("Inpatient", "Outpatient", "Drug", "Procedure"),
nameStyle = "cost_{domain}_{window_name}",
name = NULL
)
x |
A cohort table or cdm_table. |
indexDate |
Date variable in |
censorDate |
Optional date variable in |
window |
A named or unnamed list of 2-element numeric vectors. Default: |
costField |
Column name in |
domains |
Clinical domains to extract. Default: |
nameStyle |
Column naming pattern. Default: |
name |
Name of the new table in the write schema. If NULL, a temporary table is returned. |
The cohort table x with added direct medical cost columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.